==> rye-0.36.0.tar.gz: rye-0.36.0/docs/index.md <==
---
hide:
  - navigation
---

<div style="text-align: center">
  <img src="static/logo-auto.svg" style="width: 64px; margin-bottom: 10px">
  <h1><strong>Rye:</strong> a Hassle-Free Python Experience</h1>
</div>

Rye is a comprehensive project and package management solution for Python.
Born from [its creator's](https://github.com/mitsuhiko) desire to establish a
one-stop-shop for all Python users, Rye provides a unified experience to install and manages Python
installations, `pyproject.toml` based projects, dependencies and virtualenvs
seamlessly.  It's designed to accommodate complex projects, monorepos and to
facilitate global tool installations.  Curious? [Watch an introduction](https://youtu.be/q99TYA7LnuA).

A hassle-free experience for Python developers at every level.

<script async defer src="https://buttons.github.io/buttons.js"></script>
<p align="center">
  <a class="github-button" href="https://github.com/astral-sh/rye" data-size="large" data-show-count="true" data-color-scheme="light" aria-label="Star astral-sh/rye on GitHub">Star</a>
<a class="github-button" href="https://github.com/astral-sh/rye/discussions" data-icon="octicon-comment-discussion" data-size="large" aria-label="Discuss astral-sh/rye on GitHub">Discuss</a>
  <a class="github-button" href="https://github.com/sponsors/mitsuhiko" data-size="large" data-icon="octicon-heart" data-color-scheme="light" aria-label="Sponsor @mitsuhiko on GitHub">Sponsor</a>
</p>

!!! abstract "Installation Instructions"

    {% include-markdown ".includes/quick-install.md" %}

    For the next steps or ways to customize the installation, head over to the detailed
    [installation](./guide/installation.md) guide.

==> rye-0.44.0.tar.gz: rye-0.44.0/docs/index.md <==
---
hide:
  - navigation
---

<div style="text-align: center">
  <img src="static/logo-auto.svg" style="width: 64px; margin-bottom: 10px">
  <h1><strong>Rye:</strong> a Hassle-Free Python Experience</h1>
</div>

!!! note

    If you're getting started with Rye, consider [uv](https://github.com/astral-sh/uv), the
    [successor project](https://lucumr.pocoo.org/2024/2/15/rye-grows-with-uv/) from the same maintainers.

    While Rye is actively maintained, uv offers a more stable and feature-complete experience, and is the recommended
    choice for new projects.

    Having trouble migrating? [Let us know what's missing.](https://github.com/astral-sh/rye/discussions/1342)

Rye is a comprehensive project and package management solution for Python.
Born from [its creator's](https://github.com/mitsuhiko) desire to establish a
one-stop-shop for all Python users, Rye provides a unified experience to install and manages Python
installations, `pyproject.toml` based projects, dependencies and virtualenvs
seamlessly.  It's designed to accommodate complex projects, monorepos and to
facilitate global tool installations.  Curious? [Watch an introduction](https://youtu.be/q99TYA7LnuA).

A hassle-free experience for Python developers at every level.

<script async defer src="https://buttons.github.io/buttons.js"></script>
<p align="center">
  <a class="github-button" href="https://github.com/astral-sh/rye" data-size="large" data-show-count="true" data-color-scheme="light" aria-label="Star astral-sh/rye on GitHub">Star</a>
<a class="github-button" href="https://github.com/astral-sh/rye/discussions" data-icon="octicon-comment-discussion" data-size="large" aria-label="Discuss astral-sh/rye on GitHub">Discuss</a>
  <a class="github-button" href="https://github.com/sponsors/mitsuhiko" data-size="large" data-icon="octicon-heart" data-color-scheme="light" aria-label="Sponsor @mitsuhiko on GitHub">Sponsor</a>
</p>

!!! abstract "Installation Instructions"

    {% include-markdown ".includes/quick-install.md" %}

    For the next steps or ways to customize the installation, head over to the detailed
    [installation](./guide/installation.md) guide.
